summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoComplexText.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoComplexText.h')
-rw-r--r--lib/kotext/KoComplexText.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kotext/KoComplexText.h b/lib/kotext/KoComplexText.h
index f4f4253f..72abfbed 100644
--- a/lib/kotext/KoComplexText.h
+++ b/lib/kotext/KoComplexText.h
@@ -74,15 +74,15 @@ struct TQ_EXPORT KoBiditqStatus {
};
struct TQ_EXPORT KoBidiContext : public TQShared {
- // ### ref and deref tqparent?
- KoBidiContext( uchar level, TQChar::Direction embedding, KoBidiContext *tqparent = 0, bool override = FALSE );
+ // ### ref and deref parent?
+ KoBidiContext( uchar level, TQChar::Direction embedding, KoBidiContext *parent = 0, bool override = FALSE );
~KoBidiContext();
unsigned char level;
bool override : 1;
TQChar::Direction dir : 5;
- KoBidiContext *tqparent;
+ KoBidiContext *parent;
};
struct TQ_EXPORT KoBidiControl {